@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2018. Christian Heller.
+ * Copyright (C) 1999-2020. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.20.0 2018-06-30
+ * @version CYBOP 0.21.0 2020-07-29
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -77,6 +77,16 @@ static int* NAME_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1008_INTEGER_STATE_CYBOI
 /** The type get access logic cyboi format. */
 static int* TYPE_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1009_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+//
+// activate
+//
+
+/** The disable activate logic cyboi format. */
+static int* DISABLE_ACTIVATE_LOGIC_CYBOI_FORMAT = NUMBER_1020_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The enable activate logic cyboi format. */
+static int* ENABLE_ACTIVATE_LOGIC_CYBOI_FORMAT = NUMBER_1021_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 //
 // calculate
 //
@@ -363,12 +373,6 @@ static int* SEQUENCE_FLOW_LOGIC_CYBOI_FORMAT = NUMBER_1702_INTEGER_STATE_CYBOI_M
 /** The exit live logic cyboi format. */
 static int* EXIT_LIVE_LOGIC_CYBOI_FORMAT = NUMBER_1800_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The interrupt live logic cyboi format. */
-static int* INTERRUPT_LIVE_LOGIC_CYBOI_FORMAT = NUMBER_1801_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The sense live logic cyboi format. */
-static int* SENSE_LIVE_LOGIC_CYBOI_FORMAT = NUMBER_1802_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 //
 // logify
 //
