@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2018. Christian Heller.
+ * Copyright (C) 1999-2020. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.20.0 2018-06-30
+ * @version CYBOP 0.21.0 2020-07-29
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -30,6 +30,8 @@
 #include "../../applicator/access/get.c"
 #include "../../applicator/access/get_index.c"
 #include "../../applicator/access/indicate.c"
+#include "../../applicator/activate/disable.c"
+#include "../../applicator/activate/enable.c"
 #include "../../applicator/calculate/calculate.c"
 #include "../../applicator/cast/cast.c"
 #include "../../applicator/command/archive_file.c"
@@ -83,8 +85,6 @@
 #include "../../applicator/flow/branch.c"
 #include "../../applicator/flow/loop.c"
 #include "../../applicator/flow/sequence.c"
-#include "../../applicator/live/interrupt.c"
-#include "../../applicator/live/sense.c"
 #include "../../applicator/logify/logify.c"
 #include "../../applicator/maintain/shutdown.c"
 #include "../../applicator/maintain/startup.c"
@@ -232,6 +232,30 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
         }
     }
 
+    //
+    // activate
+    //
+
+    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+        compare_integer_equal((void*) &r, p7, (void*) DISABLE_ACTIVATE_LOGIC_CYBOI_FORMAT);
+
+        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            apply_disable(p0, p1, p3, p4, p2);
+        }
+    }
+
+    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+        compare_integer_equal((void*) &r, p7, (void*) ENABLE_ACTIVATE_LOGIC_CYBOI_FORMAT);
+
+        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            apply_enable(p0, p1, p3, p4, p2);
+        }
+    }
+
     //
     // calculate
     //
@@ -1094,26 +1118,6 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
         }
     }
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p7, (void*) INTERRUPT_LIVE_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_interrupt(p0, p1, p3, p4, p2);
-        }
-    }
-
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p7, (void*) SENSE_LIVE_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_sense(p0, p1, p3, p4, p2);
-        }
-    }
-
     //
     // logify
     //
@@ -1542,9 +1546,9 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, "Could not handle operation. The operation is unknown.");
-        fwprintf(stdout, L"WARNING: Could not handle operation. The operation is unknown.\n");
-        fwprintf(stdout, L"HINT: Operation format p7: %i\n", p7);
-        fwprintf(stdout, L"HINT: Operation format *p7: %i\n", *((int*) p7));
+        fwprintf(stdout, L"Warning: Could not handle operation. The operation is unknown.\n");
+        fwprintf(stdout, L"Hint: Operation format p7: %i\n", p7);
+        fwprintf(stdout, L"Hint: Operation format *p7: %i\n", *((int*) p7));
     }
 }
 
