@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2018. Christian Heller.
+ * Copyright (C) 1999-2020. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.20.0 2018-06-30
+ * @version CYBOP 0.21.0 2020-07-29
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -56,7 +56,7 @@
 //
 
 void deserialise_cybol_part(void* p0, void* p1, void* p2);
-void receive_data(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12, void* p13, void* p14, void* p15);
+void receive_data(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12, void* p13, void* p14, void* p15, void* p16);
 
 /**
  * Deserialises the cybol part element content.
@@ -298,14 +298,14 @@ void deserialise_cybol_part_element_content(void* p0, void* p1, void* p2, void*
         copy_array_forward((void*) &td, t, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
 
 /*??
-fwprintf(stdout, L"TEST content element part cybol deserialiser *slmc: %i\n", *((int*) slmc));
-fwprintf(stdout, L"TEST content element part cybol deserialiser slmd: %i\n", slmd);
-fwprintf(stdout, L"TEST content element part cybol deserialiser *slmd: %ls\n", (wchar_t*) slmd);
-fwprintf(stdout, L"TEST content element part cybol deserialiser sfmc: %i\n", *((int*) sfmc));
-fwprintf(stdout, L"TEST content element part cybol deserialiser sfmd: %i\n", sfmd);
-fwprintf(stdout, L"TEST content element part cybol deserialiser *sfmd: %ls\n", (wchar_t*) sfmd);
-fwprintf(stdout, L"TEST content element part cybol deserialiser fd: %i\n", *((int*) fd));
-fwprintf(stdout, L"TEST content element part cybol deserialiser td: %i\n", *((int*) td));
+        fwprintf(stdout, L"TEST content element part cybol deserialiser *slmc: %i\n", *((int*) slmc));
+        fwprintf(stdout, L"TEST content element part cybol deserialiser slmd: %i\n", slmd);
+        fwprintf(stdout, L"TEST content element part cybol deserialiser *slmd: %ls\n", (wchar_t*) slmd);
+        fwprintf(stdout, L"TEST content element part cybol deserialiser sfmc: %i\n", *((int*) sfmc));
+        fwprintf(stdout, L"TEST content element part cybol deserialiser sfmd: %i\n", sfmd);
+        fwprintf(stdout, L"TEST content element part cybol deserialiser *sfmd: %ls\n", (wchar_t*) sfmd);
+        fwprintf(stdout, L"TEST content element part cybol deserialiser fd: %i\n", *((int*) fd));
+        fwprintf(stdout, L"TEST content element part cybol deserialiser td: %i\n", *((int*) td));
 */
 
         // Allocate part.
@@ -358,8 +358,8 @@ fwprintf(stdout, L"TEST content element part cybol deserialiser td: %i\n", *((in
         // with elements pointing to different memory areas now.
         copy_array_forward((void*) &pld, pl, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
 
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser 1 ped: %i\n", ped);
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser 1 *ped: %i\n", *((int*) ped));
+        //?? fwprintf(stdout, L"TEST content element part cybol deserialiser 1 ped: %i\n", ped);
+        //?? fwprintf(stdout, L"TEST content element part cybol deserialiser 1 *ped: %i\n", *((int*) ped));
 
         //?? TODO: Delete this block below in the future.
         //?? ALL xml attributes should be specified in cybol,
@@ -427,8 +427,8 @@ fwprintf(stdout, L"TEST content element part cybol deserialiser td: %i\n", *((in
             }
         }
 
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser 2 ped: %i\n", ped);
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser 2 *ped: %i\n", *((int*) ped));
+        //?? fwprintf(stdout, L"TEST content element part cybol deserialiser 2 ped: %i\n", ped);
+        //?? fwprintf(stdout, L"TEST content element part cybol deserialiser 2 *ped: %i\n", *((int*) ped));
 
         // Fill part model item taken from cybol source part properties.
         // CAUTION! What is the properties in a parsed xml/cybol file,
@@ -439,12 +439,13 @@ fwprintf(stdout, L"TEST content element part cybol deserialiser td: %i\n", *((in
         // When reading cybol, the only possible two channels are "inline" and "file",
         // but the internal memory (second-last parametre) is only necessary for
         // "terminal", "display" and similar channels.
-        receive_data(pm, *NULL_POINTER_STATE_CYBOI_MODEL, smmd, smmc, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, fd, pld, ped, pcd);
+        receive_data(pm, *NULL_POINTER_STATE_CYBOI_MODEL, smmd, smmc, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, fd, pld, ped, pcd);
         // Fill part properties item taken from cybol source part model.
         // CAUTION! What is the model hierarchy in a parsed xml/cybol file,
         // becomes the properties (meta data) in the cyboi-internal knowledge tree.
         deserialise_cybol_part(pp, p1, p2);
 
+/*??
         //?? TEST ONLY:
         if (pld != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
@@ -452,16 +453,17 @@ fwprintf(stdout, L"TEST content element part cybol deserialiser td: %i\n", *((in
 
             if (*pldi == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE) {
 
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser *smmc: %i\n", *((int*) smmc));
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser smmd: %s\n", (char*) smmd);
+                //?? fwprintf(stdout, L"TEST content element part cybol deserialiser *smmc: %i\n", *((int*) smmc));
+                //?? fwprintf(stdout, L"TEST content element part cybol deserialiser smmd: %s\n", (char*) smmd);
                 void* testd = *NULL_POINTER_STATE_CYBOI_MODEL;
                 void* testc = *NULL_POINTER_STATE_CYBOI_MODEL;
                 copy_array_forward((void*) &testc, pm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
                 copy_array_forward((void*) &testd, pm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser *testc: %i\n", *((int*) testc));
-//?? fwprintf(stdout, L"TEST content element part cybol deserialiser testd: %s\n", (char*) testd);
+                //?? fwprintf(stdout, L"TEST content element part cybol deserialiser *testc: %i\n", *((int*) testc));
+                //?? fwprintf(stdout, L"TEST content element part cybol deserialiser testd: %s\n", (char*) testd);
             }
         }
+*/
 
         // Add part to destination.
         // CAUTION! Use PART_ELEMENT_STATE_CYBOI_TYPE and NOT just POINTER_STATE_CYBOI_TYPE here.
