@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2018. Christian Heller.
+ * Copyright (C) 1999-2020. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.20.0 2018-06-30
+ * @version CYBOP 0.21.0 2020-07-29
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -29,6 +29,7 @@
 #include "../../../../constant/format/cyboi/logic_cyboi_format.c"
 #include "../../../../constant/language/cyboi/state_cyboi_language.c"
 #include "../../../../constant/language/cybol/state/chronology_state_cybol_language.c"
+#include "../../../../constant/language/cybol/state/event_state_cybol_language.c"
 #include "../../../../constant/language/cybol/state/interface_state_cybol_language.c"
 #include "../../../../constant/language/cybol/state/message_state_cybol_language.c"
 #include "../../../../constant/language/cybol/state/text_state_cybol_language.c"
@@ -217,6 +218,20 @@ void deserialise_cybol_language(void* p0, void* p1, void* p2) {
         }
     }
 
+    //
+    // event
+    //
+
+    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+        check_operation((void*) &r, p1, (void*) GUI_EVENT_STATE_CYBOL_LANGUAGE, p2, (void*) GUI_EVENT_STATE_CYBOL_LANGUAGE_COUNT, (void*) EQUAL_COMPARE_LOGIC_CYBOI_FORMAT, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+
+        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            modify_item(p0, (void*) GUI_EVENT_STATE_CYBOI_LANGUAGE, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) OVERWRITE_MODIFY_LOGIC_CYBOI_FORMAT);
+        }
+    }
+
     //
     // interface
     //
