@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2018. Christian Heller.
+ * Copyright (C) 1999-2020. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.20.0 2018-06-30
+ * @version CYBOP 0.21.0 2020-07-29
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -321,6 +321,17 @@ void serialise_tui_properties(void* p0, void* p1, void* p2, void* p3, void* p4,
     // Serialise rectangle border and area.
     serialise_tui_rectangle(p0, p1, (void*) &pmdx, (void*) &smdx, (void*) &pmdy, (void*) &smdy, bomd, bomc);
 
+/*??
+    fwprintf(stdout, L"TEST: Serialise tui properties. pmdx: %i\n", pmdx);
+    fwprintf(stdout, L"TEST: Serialise tui properties. pmdy: %i\n", pmdy);
+    fwprintf(stdout, L"TEST: Serialise tui properties. smdx: %i\n", smdx);
+    fwprintf(stdout, L"TEST: Serialise tui properties. smdy: %i\n", smdy);
+    fwprintf(stdout, L"TEST: Serialise tui properties. wpmdx: %i\n", wpmdx);
+    fwprintf(stdout, L"TEST: Serialise tui properties. wpmdy: %i\n", wpmdy);
+    fwprintf(stdout, L"\n");
+*/
+
+    //
     // This function call is important for two reasons:
     //
     // 1 Reset cursor position, so that following embedded
@@ -331,6 +342,7 @@ void serialise_tui_properties(void* p0, void* p1, void* p2, void* p3, void* p4,
     //   place the cursor at a special input field.
     //   The "serialise_*_character" functions are NOT
     //   achieving this, since loops won't run with zero count.
+    //
     serialise_tui_origo(p0, p1, (void*) &pmdx, (void*) &pmdy, p9);
 }
 
